@@ -24,6 +24,7 @@
 #include <assert.h>
 #include "util.h"
 
+#include "util.h"
 #include "ksba.h"
 #include "asn1-func.h"
 #include "ber-decoder.h"
@@ -198,7 +199,7 @@ eof_or_error (BerDecoder d, int premature)
 static const char *
 universal_tag_name (unsigned long no)
 {
-  static const char *names[31] = {
+  static const char * const names[31] = {
     "[End Tag]",
     "BOOLEAN",
     "INTEGER",
