@@ -35,10 +35,12 @@ _ksba_parse_algorithm_identifier2 (const unsigned char *der, size_t derlen,
 
 
 gpg_error_t _ksba_keyinfo_to_sexp (const unsigned char *der, size_t derlen,
-                                 ksba_sexp_t *r_string);
+                                   ksba_sexp_t *r_string)
+     _KSBA_VISIBILITY_DEFAULT;
 
 gpg_error_t _ksba_keyinfo_from_sexp (ksba_const_sexp_t sexp,
-                                   unsigned char **r_der, size_t *r_derlen);
+                                     unsigned char **r_der, size_t *r_derlen)
+     _KSBA_VISIBILITY_DEFAULT;
 
 gpg_error_t _ksba_sigval_to_sexp (const unsigned char *der, size_t derlen,
                                 ksba_sexp_t *r_string);
