@@ -5,7 +5,7 @@
  *
  * KSBA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * KSBA is distributed in the hope that it will be useful,
@@ -14,9 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
- * USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 /*-- sha1.c --*/
@@ -157,6 +155,57 @@ print_sexp (ksba_const_sexp_t p)
     }
 }
 
+/* Variant of print_sexp which force printing the values in hex.  */
+void
+print_sexp_hex (ksba_const_sexp_t p)
+{
+  int level = 0;
+
+  if (!p)
+    fputs ("[none]", stdout);
+  else
+    {
+      for (;;)
+        {
+          if (*p == '(')
+            {
+              putchar (*p);
+              p++;
+              level++;
+            }
+          else if (*p == ')')
+            {
+              putchar (*p);
+              if (--level <= 0 )
+                return;
+            }
+          else if (!digitp (p))
+            {
+              fputs ("[invalid s-exp]", stdout);
+              return;
+            }
+          else
+            {
+              char *endp;
+              unsigned long len, n;
+
+              len = strtoul (p, &endp, 10);
+              p = endp;
+              if (*p != ':')
+                {
+                  fputs ("[invalid s-exp]", stdout);
+                  return;
+                }
+              p++;
+              putchar('#');
+              for (n=0; n < len; n++, p++)
+                printf ("%02X", *p);
+              putchar('#');
+            }
+        }
+    }
+}
+
 
 void
 print_dn (char *p)
